@@ -121,6 +121,9 @@ public:
     /// @return true (local paths are always available)
     bool available() const;
 
+    /// Check if path is offsite
+    bool offsite() const;
+
     /// Touch the path. The path leading to it is created if it does not exist.
     void touch() const;
 
@@ -208,7 +211,10 @@ public:
     const std::string& path() const;
 
     /// Hash the contents of this pathname (only valid for files)
-    void hash(eckit::Hash&) const;
+    void hash(Hash&) const;
+
+    /// Hash a path as in-place as possible. Returns the hash digest
+    std::string hash(const std::string& method="xxh64") const;
 
     /// Get child files and directories
     /// @param files vector to be filled with child files of path
