@@ -9,7 +9,7 @@
  */
 
 #include "eckit/config/Resource.h"
-#include "eckit/net/NetAddress.h"
+#include "eckit/net/Endpoint.h"
 #include "eckit/runtime/Application.h"
 
 using namespace eckit;
@@ -18,18 +18,17 @@ class Test : public Application {
     virtual void run();
 
 public:
-    Test(int argc, char** argv) : Application(argc, argv, "HOME") {}
+    Test(int argc, char** argv) :
+        Application(argc, argv, "HOME") {}
 };
 
 
 void Test::run() {
-    NetAddress addr(Resource<std::string>("-addr;$ADDR;addr", "localhost:9000"));
+    net::Endpoint addr(Resource<std::string>("-addr;$ADDR;addr", "localhost:9000"));
 
     Log::info() << addr << std::endl;
 }
 
-//=============================================================
-
 int main(int argc, char** argv) {
     Test app(argc, argv);
     app.start();
